@@ -7,7 +7,7 @@
 // vim: ts=4 sts=4 sw=4 expandtab
 
 // Add semicolon to prevent IIFE from being passed as argument to concatenated code.
-;
+; // eslint-disable-line no-extra-semi
 
 // UMD (Universal Module Definition)
 // see https://github.com/umdjs/umd/blob/master/templates/returnExports.js
@@ -73,13 +73,13 @@
                 return object.constructor.prototype;
             } else if (object instanceof Object) {
                 return prototypeOfObject;
-            } else {
-                // Correctly return null for Objects created with `Object.create(null)`
-                // (shammed or native) or `{ __proto__: null}`.  Also returns null for
-                // cross-realm objects on browsers that lack `__proto__` support (like
-                // IE <11), but that's the best we can do.
-                return null;
             }
+            // Correctly return null for Objects created with `Object.create(null)`
+            // (shammed or native) or `{ __proto__: null}`.  Also returns null for
+            // cross-realm objects on browsers that lack `__proto__` support (like
+            // IE <11), but that's the best we can do.
+            return null;
+
         };
     }
 
@@ -492,9 +492,9 @@
             return function freeze(object) {
                 if (typeof object === 'function') {
                     return object;
-                } else {
-                    return freezeObject(object);
                 }
+                return freezeObject(object);
+
             };
         }(Object.freeze));
     }
