@@ -12,6 +12,7 @@ var supportsDescriptors = Object.defineProperty && (function () {
         return false;
     }
 }());
+var ifSupportsDescriptorsIt = supportsDescriptors ? it : xit;
 var ifWindowIt = typeof window === 'undefined' ? xit : it;
 var extensionsPreventible = typeof Object.preventExtensions === 'function' && (function () {
     var obj = {};
@@ -247,6 +248,41 @@ describe('Object', function () {
                 Object.defineProperty({}, 'name', {});
             }).not.toThrow();
         });
+
+        ifSupportsDescriptorsIt('allows setting a nonwritable prototype', function () {
+            var F = function () {};
+            expect(F.prototype).toEqual(Object.getOwnPropertyDescriptor(F, 'prototype').value);
+            expect((new F()).toString).toEqual(Object.prototype.toString);
+
+            F.prototype = Number.prototype;
+            expect(F.prototype).toEqual(Object.getOwnPropertyDescriptor(F, 'prototype').value);
+            expect((new F()).toString).toEqual(Number.prototype.toString);
+
+            var toStringSentinel = {};
+            var sentinel = { toString: toStringSentinel };
+            Object.defineProperty(F, 'prototype', { value: sentinel, writable: false });
+
+            expect(F.prototype).toEqual(Object.getOwnPropertyDescriptor(F, 'prototype').value);
+            expect((new F()).toString).toEqual(toStringSentinel);
+        });
+
+        ifSupportsDescriptorsIt('properly makes a prototype non-writable', function () {
+            var O = { prototype: 1 };
+            expect(O.prototype).toEqual(Object.getOwnPropertyDescriptor(O, 'prototype').value);
+            expect(O.prototype).toEqual(1);
+
+            expect(function () {
+                Object.defineProperty(O, 'prototype', { writable: false, configurable: true });
+            }).not.toThrow();
+
+            var sentinel = {};
+            expect(function () {
+                Object.defineProperty(O, 'prototype', { value: sentinel });
+            }).not.toThrow();
+
+            expect(O.prototype).toEqual(Object.getOwnPropertyDescriptor(O, 'prototype').value);
+            expect(O.prototype).toEqual(sentinel);
+        });
     });
 
     describe('.getOwnPropertyDescriptor()', function () {
